import { Knex } from 'knex';
import { Task, Step, Printer } from '@shared/index';
import { TestPrinter } from './test-printer';
import { SerialPrinter } from './serial-printer';
import logger from '../logger';

export function createPrinter(): Printer {
  const printerType = process.env.PRINTER_TYPE?.toLowerCase() || 'test';

  switch (printerType) {
    case 'serial':
      logger.info('Using serial printer driver');
      return new SerialPrinter();
    case 'test':
    default:
      logger.info('Using test printer driver');
      return new TestPrinter();
  }
}

export async function printTask(task: Task, db: Knex): Promise<void> {
  const printer = createPrinter();
  await printer.printTask(task, db);
}

export async function printStep(step: Step, db: Knex): Promise<void> {
  const printer = createPrinter();
  await printer.printStep(step, db);
}