import { Knex } from 'knex';

export interface Group {
  id: number;
  name: string;
  parent_id?: number;
  created_at: Date;
  updated_at: Date;
}

export interface Task {
  id: number;
  name: string;
  group_id: number;
  print_count: number;
  last_printed_at?: Date;
  created_at: Date;
  updated_at: Date;
}

export interface Step {
  id: number;
  name: string;
  instructions: string;
  task_id: number;
  order: number;
  print_count: number;
  last_printed_at?: Date;
  created_at: Date;
  updated_at: Date;
}

export interface Image {
  id: number;
  step_id: number;
  original_path: string;
  bw_path: string;
  order: number;
  created_at: Date;
  updated_at: Date;
}

export interface User {
  id: number;
  name: string;
  created_at: Date;
  updated_at: Date;
}

export interface Note {
  id: number;
  content: string;
  task_id?: number;
  step_id?: number;
  created_by: number;
  created_at: Date;
  updated_at: Date;
}

export interface PrintHistory {
  id: number;
  user_id: number;
  task_id?: number;
  step_id?: number;
  printed_at: Date;
  created_at: Date;
  updated_at: Date;
}

export interface Database {
  groups: Knex.QueryBuilder<Group>;
  tasks: Knex.QueryBuilder<Task>;
  steps: Knex.QueryBuilder<Step>;
  images: Knex.QueryBuilder<Image>;
  users: Knex.QueryBuilder<User>;
  notes: Knex.QueryBuilder<Note>;
  print_history: Knex.QueryBuilder<PrintHistory>;
}

export interface Printer {
  printTask(task: Task, db: Knex): Promise<void>;
  printStep(step: Step, db: Knex): Promise<void>;
}